package com.me.brickbuster.entity.powerup;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.math.MathUtils;
import com.badlogic.gdx.math.Vector2;
import com.me.brickbuster.entity.Brick;
import com.me.brickbuster.state.PlayState;

public enum PowerUpType {

	GLUE(GluePowerUp.class, Color.WHITE, 20),
	LONGER_PADDLE(LongerPaddlePowerUp.class, Color.OLIVE, 40),
	MULTI_BALL(MultiBallPowerUp.class, Color.ROYAL, 30),
	SHIELD(ShieldPowerUp.class, Color.SALMON, 40),
	;

	private static final int WEIGHT_SUM;

	private Class<? extends PowerUp> cls;
	private Color color;
	private int weight;

	PowerUpType(Class<? extends PowerUp> cls, Color color, int weight) {
		this.cls = cls;
		this.color = color;
		this.weight = weight;
	}

	public Color getColor() {
		return color;
	}

	public static PowerUpType getWeightedRandom() {
		int distance = MathUtils.random(WEIGHT_SUM);
		for (PowerUpType type : values()) {
			distance -= type.weight;
			if (distance < 0) {
				return type;
			}
		}
		return null;
	}

	public PowerUp createInstance(PlayState state, Brick brick) {
		return createInstance(state, new Vector2(brick.getX(), brick.getY()));
	}

	public PowerUp createInstance(PlayState state, Vector2 pos) {
		try {
			return cls.getConstructor(PlayState.class, Vector2.class, Color.class)
					.newInstance(state, pos, color);
		} catch(Exception e) {
			System.out.println("Error instantiating PoewrUp: " + e.getMessage());
		}
		return null;
	}

	static {
		int weightSum = 0;
		for (PowerUpType type : values()) {
			weightSum += type.weight;
		}
		WEIGHT_SUM = weightSum;
	}

}
